@@ -25,12 +25,15 @@ assert isConnect
 fileTransfer = TFileTransfer(TFileTransfer.Type.T5, device)
 assert fileTransfer
 
-ret = fileTransfer.Start("d:\\work\\A2-655UV01-OTP-DEV190904-ANA6705_hthwang.TMD")
+#ret = fileTransfer.Start("d:\\work\\A2-655UV01-OTP-DEV190904-ANA6705_hthwang.TMD")
 #ret = fileTransfer.Start("D:\Work\업무\AAA-업무 완성\2. Product\A2-655UV01-OTP-DEV190904-ANA6705_hthwang.TMD")
 #ret = fileTransfer.Start("D:\Work\업무\AAA-업무 완성\2.Product\A2-655UV01-OTP-DEV190904-ANA6705_hthwang.TMD")
 #ret = fileTransfer.Start("D:\\Work\\업무\\AAA-업무 완성\\2Product\\A2-655UV01-OTP-DEV190904-ANA6705_hthwang.TMD")
 #ret = fileTransfer.Start("D:\\Work\업무\AAA-업무 완성\Product\A2-655UV01-OTP-DEV190904-ANA6705_hthwang.TMD")
 #ret = fileTransfer.Start("D:\Work\업무\AAA-업무 완성\A2-655UV01-OTP-DEV190904-ANA6705_hthwang.TMD")
+
+# hht12/hht13 은 이름만 다른 같은 파일이다.  
+ret = fileTransfer.Start("\\\\nas\\13_Data\\SoC\\SoC_SI\\업무공유\\2. Product\\ANA6705(FHD+)\\3. EEPROM_TMD_VEC\\TMD\\HHT\\TMD-전송-Test\\A2-655UV01-OTP-DEV190904-ANA6705_hht12.TMD")
 #ret = fileTransfer.Start("\\\\nas\\13_Data\\SoC\\SoC_SI\\업무공유\\2. Product\\ANA6705(FHD+)\\3. EEPROM_TMD_VEC\\TMD\\HHT\\TMD-전송-Test\\A2-655UV01-OTP-DEV190904-ANA6705_hht13.TMD")
 #ret = fileTransfer.Start("\\\\nas\\13_Data\\SoC\\SoC_SI\\업무공유\\2. Product\\ANA6705(FHD+)\\3. EEPROM_TMD_VEC\\TMD\\HHT\\MAIN_V5_190624.dll")
 
